import requests


class Contact:

    def __init__(self, api_token):
        self.api_token = api_token
        self.base = "https://connect.nicapi.eu/api/v1/{endpoint}?authToken={API_TOKEN}"

    def get_handle(self, handle):
        """
        RETURNS ONE DOMAIN HANDLE
        :param handle: HANDLE ID
        :return: RETURNS DECODED LIST
        """
    
        r = requests.get(self.base.format(endpoint="domain/handles/show", API_TOKEN=self.api_token), params={
            "handle": handle
        })
    
        return r.json()

    def get_countries(self):
        """
        RETURNS ALL AVAILABLE COUNTRIES
        :return: RETURNS DECODED LIST
        """
    
        r = requests.get(self.base.format(endpoint="domain/handles/countries", API_TOKEN=self.api_token))
    
        return r.json()

    def create_handle(self, handle_type, sex, firstname, lastname, organisation, street, number, postcode, city, region,
                      country, email, phone, countryofbirth=None, user=None, dateofbirth=None):
        """
        CREATES A DOMAIN CONTACT
        :return:
        :param handle_type:
        :param sex:
        :param firstname:
        :param lastname:
        :param organisation:
        :param street:
        :param number:
        :param postcode:
        :param city:
        :param region:
        :param country:
        :param email:
        :param phone:
        :param countryofbirth: OPTIONAL
        :param user: OPTIONAL
        :param dateofbirth: OPTIONAL
        :return:
        """
    
        r = requests.post(self.base.format(endpoint="domain/handles/create", API_TOKEN=self.api_token), params={
            "type": handle_type,
            "sex": sex,
            "firstname": firstname,
            "lastname": lastname,
            "organisation": organisation,
            "street": street,
            "number": number,
            "postcode": postcode,
            "city": city,
            "region": region,
            "country": country,
            "email": email,
            "phone": phone,
            "countryofbirth": countryofbirth,
            "user": user,
            "dateofbirth": dateofbirth
        })
    
        return r.json()

    def delete_handle(self, handle):
        """
        DELETE A CREATED CONTACT/HANDLE
        :param api_token:
        :param handle:
        :return:
        """
    
        r = requests.delete(self.base.format(endpoint="domain/handles/delete", API_TOKEN=self.api_token), params={
            "handle": handle
        })
    
        return r.json()

    def edit_handle(self, handle, street, number, postcode, city, region, country, email, phone,
                    countryofbirth=None, user=None, organisation=None):
        """
        EDIT A CREATED CONTACT/HANDLE
        :param handle:
        :param organisation:
        :param street:
        :param number:
        :param postcode:
        :param city:
        :param region:
        :param country:
        :param email:
        :param phone:
        :param countryofbirth:
        :param user:
        :return:
        """
    
        r = requests.post(self.base.format(endpoint="domain/handles/edit", API_TOKEN=self.api_token), params={
            "handle": handle,
            "organisation": organisation,
            "street": street,
            "number": number,
            "postcode": postcode,
            "city": city,
            "region": region,
            "country": country,
            "email": email,
            "phone": phone,
            "countryofbirth": countryofbirth,
            "user": user
        })
    
        return r.json()



import requests

# DECLARES THE self.base URL OF THE API


class Domain:

    def __init__(self, api_token):
        self.api_token = api_token
        self.base = "https://connect.nicapi.eu/api/v1/{endpoint}?authToken={API_TOKEN}"

    def get_domains(self):
        """
        RETURNS ALL ASSIGNED DOMAINS.
        :return: RETURNS DECODED LIST
        """

        r = requests.get(self.base.format(endpoint="domain/domains", API_TOKEN=self.api_token))

        return r.json()

    def get_domain(self, domain):
        """
        RETURNS INFORMATION ABOUT ONE DOMAIN
        :param domain: DECLARES THE DOMAIN TO BE USED
        :return: RETURNS LIST
        """

        r = requests.get(self.base.format(endpoint="domain/domains/show", API_TOKEN=self.api_token), params={
            "domainName": domain
        })

        return r.json()

    def get_auth_info(self, domain):
        """
        RETURNS INFORMATION ABOUT THE AUTH CODE
        :param domain: DECLARES THE DOMAIN TO BE USED
        :return: RETURNS LIST
        """

        r = requests.post(self.base.format(endpoint="domain/domains/authcode", API_TOKEN=self.api_token), params={
            "domainName": domain
        })

        return r.json()

    def get_auth_code(self, domain):
        """
           RETURNS THE AUTH CODE FOR ONE DOMAIN
           :param domain: DECLARES THE DOMAIN TO BE USED
           :return: RETURNS LIST
           """

        return self.get_auth_info(self.api_token, domain)["data"]["domain"]["authinfo"]

    def check_availability(self, domain):
        """
        RETURNS INFORMATION ABOUT THE AUTH CODE
        :param domain: DECLARES THE DOMAIN TO BE USED
        :return: RETURNS LIST
        """

        r = requests.post(self.base.format(endpoint="domain/domains/check", API_TOKEN=self.api_token), params={
            "domainName": domain
        })

        return r.json()

    def order_domain(self, domainName, ownerC, adminC, techC, zoneC, ns1, ns2, ns3=None, ns4=None, ns5=None,
                     user=None,
                     years=1, create_zone=None, authinfo=None):
        """
        ORDERS A DOMAINS
        :param authinfo:
        :param create_zone:
        :param years:
        :param user:
        :param ns5:
        :param ns4:
        :param ns3:
        :param ns2:
        :param ns1:
        :param zoneC:
        :param techC:
        :param adminC:
        :param ownerC:
        :param domainName:
        :return: RETURNS LIST
        """

        r = requests.post(self.base.format(endpoint="domain/domains/create", API_TOKEN=self.api_token), params={
            "domainName": domainName,
            "ownerC": ownerC,
            "adminC": adminC,
            "techC": techC,
            "zoneC": zoneC,
            "ns1": ns1,
            "ns2": ns2,
            "ns3": ns3,
            "ns4": ns4,
            "ns5": ns5,
            "user": user,
            "years": years,
            "create_zone": create_zone,
            "authinfo": authinfo
        })

        return r.json()

    def delete_domain(self, domainName, date=None):
        """
        Deletes a domain.
        :param domainName:
        :param date: OPTIONAL
        :return:
        """
        r = requests.delete(self.base.format(endpoint="domain/domains/delete", API_TOKEN=self.api_token), params={
            "domainName": domainName,
            "date": date
        })

        return r.json()

    def undelete_domain(self, domainName):
        """
        Removes the deletion task if date for deletion was set.
        :param domainName:
        :return:
        """
        r = requests.post(self.base.format(endpoint="domain/domains/undelete", API_TOKEN=self.api_token), params={
            "domainName": domainName,
        })

        return r.json()

    def update_domain(self, domainName, ownerC, adminC, techC, zoneC, ns1, ns2, ns3=None, ns4=None, ns5=None,
                      user=None):
        """
        Updates A DOMAINS
        :param user:
        :param ns5:
        :param ns4:
        :param ns3:
        :param ns2:
        :param ns1:
        :param zoneC:
        :param techC:
        :param adminC:
        :param ownerC:
        :param domainName:
        :return: RETURNS LIST
        """

        r = requests.post(self.base.format(endpoint="domain/domains/edit", API_TOKEN=self.api_token), params={
            "domainName": domainName,
            "ownerC": ownerC,
            "adminC": adminC,
            "techC": techC,
            "zoneC": zoneC,
            "ns1": ns1,
            "ns2": ns2,
            "ns3": ns3,
            "ns4": ns4,
            "ns5": ns5,
            "user": user,
        })

        return r.json()

    def restore_domain(self, domainName):
        """
        RESTORES A DOMAINS
        :param domainName:
        :return: RETURNS LIST
        """

        r = requests.post(self.base.format(endpoint="domain/domains/restore", API_TOKEN=self.api_token), params={
            "domainName": domainName,
        })

        return r.json()

    def get_tlds(self):
        """
        FETCHES ALL AVAILABLE TLDs
        :return: RETURNS LIST
        """

        r = requests.get(self.base.format(endpoint="domain/domains/tlds", API_TOKEN=self.api_token))

        return r.json()

    def get_domain_prices(self):
        """
        FETCHES THE CURRENT PRICING
        :return: RETURNS LIST
        """

        r = requests.get(self.base.format(endpoint="accounting/pricing/domains", API_TOKEN=self.api_token))

        return r.json()

    def get_domain_discounts(self):
        """
        FETCHES THE CURRENT DOMAIN DISCOUNTS
        :return: RETURNS LIST
        """

        r = requests.get(self.base.format(endpoint="accounting/pricing/domains/discounts", API_TOKEN=self.api_token))

        return r.json()



import requests


class DomainZones:

    def __init__(self, api_token):
        self.api_token = api_token
        self.base = "https://connect.nicapi.eu/api/v1/{endpoint}?authToken={API_TOKEN}"

    def get_zones(self):
        """
        Fetches all zones
        :return:
        """
        r = requests.get(self.base.format(endpoint="dns/zones", API_TOKEN=self.api_token))

        return r.json()

    def get_zone(self, zone):
        """
        Fetches one zone
        :param zone:
        :return:
        """
        r = requests.get(self.base.format(endpoint="dns/zones/show", API_TOKEN=self.api_token), params={
            "zone": zone
        })

        return r.json()

    def add_entry(self, zone, records):
        """
        Adds the requested entrys. Please keep in mind: records is an array. Please read the API Docs.
        :param zone:
        :param records: array
        :return:
        """

        r = requests.post(self.base.format(endpoint="dns/zones/records/add", API_TOKEN=self.api_token), params={
            "zone": zone,
            "records": records,
        })

        return r.json()

    def remove_entry(self, zone, records):
        """
        removed one or more entrys. Please provide the full record which should be deleted.
        :param zone: Zone ID
        :param records: array(name, ttl, type, data)
        :return:
        """

        r = requests.delete(self.base.format(endpoint="/dns/zones/records/delete", API_TOKEN=self.api_token), params={
            "zone": zone,
            "records": records,
        })

        return r.json()

    def refresh_zone(self, zone):
        """
        Refreshes the zone on the nameserver
        :param zone:
        :return:
        """

        r = requests.post(self.base.format(endpoint="/dns/zones/refresh", API_TOKEN=self.api_token), params={
            "zone": zone,
        })

        return r.json()



import requests


class Nameserver:

    def __init__(self, api_token):
        self.api_token = api_token
        self.base = "https://connect.nicapi.eu/api/v1/{endpoint}?authToken={API_TOKEN}"

    def get_nameservers(self):
        """
        FETCHES ALL ASSIGNED NAMESERVERS
        :return:
        """

        r = requests.get(self.base.format(endpoint="domain/nameservers", API_TOKEN=self.api_token))

        return r.json()

    def get_nameserver(self, nameserver):
        """
        GET INFORMATION FOR ONE NAMESERVER
        :param nameserver:
        :return:
        """

        r = requests.get(self.base.format(endpoint="domain/nameservers/show", API_TOKEN=self.api_token), params={
            "nameserver": nameserver
        })

        return r.json()

    def create_nameserver(self, nameserver):
        """
        CREATES A NEW NAMESERVER
        :param nameserver:
        :return:
        """

        r = requests.post(self.base.format(endpoint="domain/nameservers/create", API_TOKEN=self.api_token), params={
            "nameserver": nameserver
        })

        return r.json()

    def delete_nameserver(self, nameserver):
        """
        DELETES A CREATED NAMESERVER
        :param nameserver:
        :return:
        """

        r = requests.delete(self.base.format(endpoint="domain/nameservers/delete", API_TOKEN=self.api_token), params={
            "nameserver": nameserver
        })

        return r.json()

    def update_namserver(self, nameserver):
        """
        UPDATED A  NAMESERVER
        :param nameserver:
        :return:
        """

        r = requests.post(self.base.format(endpoint="domain/nameservers/refresh", API_TOKEN=self.api_token), params={
            "nameserver": nameserver
        })

        return r.json()
